local _, ns = ...
local WK = ns.WhoKnows
---
--- @module WhoKnows
---
-- @debug @
-- @end - d e b u g @
-------------------------------------------------------
WK.recipeDb = LibStub("LibRecipes-1.0")
WK.WKEvFrame = CreateFrame("FRAME", "WKEvFrame")
WK.DebugTable = {}
WK.lineAdded = false

-------------------------------------------------------
local function timestamp()
	local t = date("*t")
	local ampm = t.hour <= 11 and "AM" or "PM"
	local _hour = t.hour
	if t.hour > 12 then _hour = t.hour - 12 end
	return string.format("|cffff8000[%s:%s:%s %s]|r ", _hour, t.min, t.sec, ampm)
end

WK.debugPrint = (function(...)
	if (WK.debug ~= true) then return end
	WK.DebugBox:Show()
	local ts = timestamp()
	local arg1, arg2, arg3 = ...
	local msg = arg1 or "NIL"
	local params = ""
	if msg == "Event" then
		if (arg3 and type(arg3) == "table") then
			for i = 1, #arg3 do
				params = params .. "arg" .. i .. ": " .. (arg3[i] or "nada") .. "  |  "
			end
		elseif (arg3 and type(arg3) == "string") then
			params = arg3
		end
		if params == "" then params = "No Returns" end
		WK.DebugBox:AddLine(ts .. "|cffa335eeWhoKnows |cffff0000Debug Event:|r " .. arg2 .. " Returns: " .. params)
	else
		WK.DebugBox:AddLine(ts .. "|cffa335eeWhoKnows |cffff0000Debug:|r " .. msg)
	end
	if strmatch(msg,"WARNING") then
		PlaySoundFile("Sound\\Spells\\AbolishMagic.wav")
	end
end)
WK.print = function(...) print("|cffa335eeWhoKnows:|r ", ...) end
WK.error = function(...)
	print("|cffff0000WhoKnows Error:|r " .. string.format(...))
	PlaySoundFile("Sound\\Spells\\AbolishMagic.wav")
end

WK.debugPrintUI = function(strName, tData)
    if ViragDevTool_AddData and WK.debug == true then
        ViragDevTool_AddData(tData, strName)
    end
end
-------------------------------------------------------

--- @type WK.Character
WK.Character = {}
WK.Character.__index = WK.Character

--- @return #WK.Character
function WK.Character:New()
	local self = {}
	setmetatable(self, WK.Character)
	self.name = GetUnitName("player")
	self.race = UnitRace("player")
	self.class = UnitClass("player")
	self.faction = UnitFactionGroup("player")
	self.level = UnitLevel("player")
	self.realm = GetRealmName()
	self.guid = UnitGUID("player")
	self.player = nil
	return self;
end

function WK.Character:SetPlayer()
	self.player = WhoKnows_Data.Skills[self.realm][self.faction][self.name]
	return self.player
end

-------------------------------------------------------
function WK.Character:GetAllCharacters(_realm)
	local results = {}
	for realm in pairs(WhoKnows_Data.Skills) do
		if _realm and _realm == realm then
			for faction in pairs(WhoKnows_Data.Skills[realm]) do
				for player in pairs(WhoKnows_Data.Skills[realm][faction]) do
					table.insert(results, { realm, faction, player })
				end
			end
		end
	end
	return results
end

-------------------------------------------------------
function WK.Character:SetPlayerError(errMsg)
	WK.debugPrint("Can't set WK.Character.player because " .. errMsg .. "  doesn't exist.")
	PlaySoundFile("Sound\\Spells\\AbolishMagic.wav")
end

-------------------------------------------------------
function WK.IsLearnableItem(_L)
	local isLearnable
	if _L and _L:match("Hitem:") then
		local itemAuctionClass = select(6, GetItemInfo(_L))
		if itemAuctionClass == "Miscellaneous" and select(7, GetItemInfo(_L)) ~= "Other" then
			return nil
		elseif itemAuctionClass == "Recipe" or itemAuctionClass == "Miscellaneous" then
			isLearnable = true
		end
	end
	return isLearnable
end
-------------------------------------------------------
function WK.IsItemLink(_I)
	local isLink
	if type(_I) == "string" then
		isLink = _I:match("|Hitem:%d") ~= nil
	end
	return isLink
end
-------------------------------------------------------
function WK.GetItemIdFromHyperlink(_h)
	local itemId
	if type(_h) == "string" then
		itemId = _h:match("|Hitem:(%d*)")
	end
	return tonumber(itemId)
end
-------------------------------------------------------
WK.skillCache = setmetatable({}, {
	__index = function(t, categoryID)
		local skillCategory = C_TradeSkillUI.GetCategoryInfo(categoryID)
		if not skillCategory then return end
		rawset(t, categoryID, skillCategory)
		table.sort(t)
		return skillCategory
	end,
})

function WK.GetSpellCategoryFromID(categoryID)
	if categoryID == nil then return end
	local skillCategory= WK.skillCache[categoryID].name
	local pCatID = WK.skillCache[categoryID].parentCategoryID
	local parentCategory
	if (pCatID) then
		parentCategory = WK.skillCache[pCatID].name
	end
	return skillCategory, parentCategory
end
-------------------------------------------------------
