local _, ns = ...
local WK = ns.WhoKnows
local debugPrint = WK.debugPrint
WK.ItemGlow = {}
----------------------------------------------------------------------------

function WK.ItemGlow:OverlaySetup(frame, itemId, index)
	if WK.IsItemLink(itemId) then
		itemId = WK.GetItemIdFromHyperlink(itemId)
	end
	local item = WK.items[itemId]
	if not item then return end
	if item.isIncomplete == true then
		WK.Itemcache.ItemIds[item.itemId] = frame
	end
	if index and type(index) == "boolean" then item.isNotLearnableYet = index
	elseif index and type(index) == "number" and not item.isKnownBySelf then --and item.isBlueprint
		item.isNotLearnableYet = not select(6, GetMerchantItemInfo(index))
	end
	local toonSearchResults = WK.PlayerStats:GetToonLearnedStatus(item)
	WK.debugPrintUI("tsr", toonSearchResults)
	if toonSearchResults then
		local color = WK.ItemGlow:AssignColor(toonSearchResults)
		if color then WK:Overlay_Show(frame, color)
		else WK.ItemGlow:Overlay_Hide(frame)
		end
	else
		WK.ItemGlow:Overlay_Hide(frame)
	end
end

function WK.ItemGlow:AssignColor(toonSearchResults)
	local player = WK.currentPlayer.name
	local color
	WK.DebugTable.tsr = toonSearchResults
	-- Priority: if self or alt can learn the spell then that will trump any other color designation
	for toon, sResult in pairs(toonSearchResults) do
		if sResult.msg:match("cff1eff00Able to learn") then
			if (toon == player and WhoKnows_Data.enableSelfLearnableColor) then
				color = WhoKnows_Data.Colors.SelfLearnableColor
			elseif WhoKnows_Data.enableAltLearnableColor then
				color = WhoKnows_Data.Colors.AltLearnableColor
			end
		elseif (WhoKnows_Data.enableNotReadyToLearnColor and
				(sResult.msg:match("cffff8000Unable to learn")
				or sResult.msg:match("|cffffe700Character's level too low")
				or sResult.msg:match("cffff8000Need to learn a lower"))) then
			color = WhoKnows_Data.Colors.NotReadyToLearnColor
		elseif (WhoKnows_Data.enableUnlearnableColor and
				(sResult.msg:match("Class restrictions:")
				or sResult.msg:match("Unlearnable:")
				or sResult.msg:match("None of your toons"))) then
			color = WhoKnows_Data.Colors.UnlearnableColor
		elseif (WhoKnows_Data.enableAlreadyKnownColor and sResult.msg:match("cff008500known")) then
			color = WhoKnows_Data.Colors.AlreadyKnownColor
		end
	end
	return color
end

function WK.ItemGlow:Overlay_Hide(frame)
	if not frame then return end
	if (frame.antsFrame) then
		frame.antsFrame:Hide();
		frame.antsFrame = nil;
	end
end

local function GetAntsFrame(f)
	local name = "antFrame_" .. f:GetName()
	local frame = _G[name]
	if (frame) then
		if (not frame:IsShown()) then
			return frame
		end
	else
		frame = CreateFrame("Frame", name, f, "AntsFrameTemplate")
		return frame
	end
end

function WK:Overlay_Show(frame, color)
	if not color then return end
	local antsFrame = frame.antsFrame;
	if (not antsFrame) then
		antsFrame = GetAntsFrame(frame);
		antsFrame:SetPoint("CENTER");
		frame.antsFrame = antsFrame;
	end
	antsFrame.ants:SetVertexColor(color[1], color[2], color[3], color[4])
	antsFrame.innerGlow:SetVertexColor(color[1], color[2], color[3], color[4] * 0.7)
	antsFrame:Show();
end
